@@ -1,3 +1,5 @@
+from eth2spec.test.context import is_post_altair, is_post_merge
+from eth2spec.test.helpers.execution_payload import build_empty_execution_payload
 from eth2spec.test.helpers.keys import privkeys
 from eth2spec.utils import bls
 from eth2spec.utils.bls import only_with_bls
@@ -59,6 +61,7 @@ def transition_unsigned_block(spec, state, block):
     assert state.latest_block_header.slot < block.slot  # There may not already be a block in this slot or past it.
     assert state.slot == block.slot  # The block must be for this slot
     spec.process_block(state, block)
+    return block
 
 
 def apply_empty_block(spec, state, slot=None):
@@ -66,7 +69,7 @@ def apply_empty_block(spec, state, slot=None):
     Transition via an empty block (on current slot, assuming no block has been applied yet).
     """
     block = build_empty_block(spec, state, slot)
-    transition_unsigned_block(spec, state, block)
+    return transition_unsigned_block(spec, state, block)
 
 
 def build_empty_block(spec, state, slot=None):
@@ -89,7 +92,15 @@ def build_empty_block(spec, state, slot=None):
     empty_block.proposer_index = spec.get_beacon_proposer_index(state)
     empty_block.body.eth1_data.deposit_count = state.eth1_deposit_index
     empty_block.parent_root = parent_block_root
+
     apply_randao_reveal(spec, state, empty_block)
+
+    if is_post_altair(spec):
+        empty_block.body.sync_aggregate.sync_committee_signature = spec.G2_POINT_AT_INFINITY
+
+    if is_post_merge(spec):
+        empty_block.body.execution_payload = build_empty_execution_payload(spec, state)
+
     return empty_block
 
 
