@@ -1,7 +1,5 @@
-from random import Random
 from eth_utils import encode_hex
 from eth2spec.test.exceptions import BlockNotFoundException
-from eth2spec.utils.ssz.ssz_typing import uint256
 from eth2spec.test.helpers.attestations import (
     next_epoch_with_attestations,
     next_slots_with_attestations,
@@ -247,15 +245,6 @@ def apply_next_slots_with_attestations(spec,
     return post_state, store, last_signed_block
 
 
-def prepare_empty_pow_block(spec, rng=Random(3131)):
-    return spec.PowBlock(
-        block_hash=spec.Hash32(spec.hash(bytearray(rng.getrandbits(8) for _ in range(32)))),
-        parent_hash=spec.Hash32(spec.hash(bytearray(rng.getrandbits(8) for _ in range(32)))),
-        total_difficulty=uint256(0),
-        difficulty=uint256(0)
-    )
-
-
 def get_pow_block_file_name(pow_block):
     return f"pow_block_{encode_hex(pow_block.block_hash)}"
 
