@@ -1,15 +1,37 @@
-from eth2spec.test.context import PHASE0, spec_test, with_phases, single_phase
+from eth2spec.test.context import (
+    is_post_altair,
+    single_phase,
+    spec_test,
+    with_presets,
+    with_all_phases,
+)
+from eth2spec.test.helpers.constants import MINIMAL
 from eth2spec.test.helpers.deposits import (
     prepare_full_genesis_deposits,
     prepare_random_genesis_deposits,
 )
 
 
-@with_phases(([PHASE0]))
+def get_post_altair_description(spec):
+    return f"Although it's not phase 0, we may use {spec.fork} spec to start testnets."
+
+
+def eth1_init_data(eth1_block_hash, eth1_timestamp):
+    yield 'eth1', {
+        'eth1_block_hash': '0x' + eth1_block_hash.hex(),
+        'eth1_timestamp': int(eth1_timestamp),
+    }
+
+
+@with_all_phases
 @spec_test
 @single_phase
+@with_presets([MINIMAL], reason="too slow")
 def test_initialize_beacon_state_from_eth1(spec):
-    deposit_count = spec.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT
+    if is_post_altair(spec):
+        yield 'description', 'meta', get_post_altair_description(spec)
+
+    deposit_count = spec.config.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT
     deposits, deposit_root, _ = prepare_full_genesis_deposits(
         spec,
         spec.MAX_EFFECTIVE_BALANCE,
@@ -18,16 +40,15 @@ def test_initialize_beacon_state_from_eth1(spec):
     )
 
     eth1_block_hash = b'\x12' * 32
-    eth1_timestamp = spec.MIN_GENESIS_TIME
+    eth1_timestamp = spec.config.MIN_GENESIS_TIME
 
-    yield 'eth1_block_hash', eth1_block_hash
-    yield 'eth1_timestamp', eth1_timestamp
+    yield from eth1_init_data(eth1_block_hash, eth1_timestamp)
     yield 'deposits', deposits
 
     # initialize beacon_state
     state = spec.initialize_beacon_state_from_eth1(eth1_block_hash, eth1_timestamp, deposits)
 
-    assert state.genesis_time == eth1_timestamp + spec.GENESIS_DELAY
+    assert state.genesis_time == eth1_timestamp + spec.config.GENESIS_DELAY
     assert len(state.validators) == deposit_count
     assert state.eth1_data.deposit_root == deposit_root
     assert state.eth1_data.deposit_count == deposit_count
@@ -38,11 +59,15 @@ def test_initialize_beacon_state_from_eth1(spec):
     yield 'state', state
 
 
-@with_phases([PHASE0])
+@with_all_phases
 @spec_test
 @single_phase
+@with_presets([MINIMAL], reason="too slow")
 def test_initialize_beacon_state_some_small_balances(spec):
-    main_deposit_count = spec.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT
+    if is_post_altair(spec):
+        yield 'description', 'meta', get_post_altair_description(spec)
+
+    main_deposit_count = spec.config.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT
     main_deposits, _, deposit_data_list = prepare_full_genesis_deposits(
         spec, spec.MAX_EFFECTIVE_BALANCE,
         deposit_count=main_deposit_count, signed=True,
@@ -58,16 +83,15 @@ def test_initialize_beacon_state_some_small_balances(spec):
     deposits = main_deposits + small_deposits
 
     eth1_block_hash = b'\x12' * 32
-    eth1_timestamp = spec.MIN_GENESIS_TIME
+    eth1_timestamp = spec.config.MIN_GENESIS_TIME
 
-    yield 'eth1_block_hash', eth1_block_hash
-    yield 'eth1_timestamp', eth1_timestamp
+    yield from eth1_init_data(eth1_block_hash, eth1_timestamp)
     yield 'deposits', deposits
 
     # initialize beacon_state
     state = spec.initialize_beacon_state_from_eth1(eth1_block_hash, eth1_timestamp, deposits)
 
-    assert state.genesis_time == eth1_timestamp + spec.GENESIS_DELAY
+    assert state.genesis_time == eth1_timestamp + spec.config.GENESIS_DELAY
     assert len(state.validators) == small_deposit_count
     assert state.eth1_data.deposit_root == deposit_root
     assert state.eth1_data.deposit_count == len(deposits)
@@ -79,12 +103,16 @@ def test_initialize_beacon_state_some_small_balances(spec):
     yield 'state', state
 
 
-@with_phases([PHASE0])
+@with_all_phases
 @spec_test
 @single_phase
+@with_presets([MINIMAL], reason="too slow")
 def test_initialize_beacon_state_one_topup_activation(spec):
+    if is_post_altair(spec):
+        yield 'description', 'meta', get_post_altair_description(spec)
+
     # Submit all but one deposit as MAX_EFFECTIVE_BALANCE
-    main_deposit_count = spec.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT - 1
+    main_deposit_count = spec.config.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT - 1
     main_deposits, _, deposit_data_list = prepare_full_genesis_deposits(
         spec, spec.MAX_EFFECTIVE_BALANCE,
         deposit_count=main_deposit_count, signed=True,
@@ -111,10 +139,9 @@ def test_initialize_beacon_state_one_topup_activation(spec):
     deposits = main_deposits + partial_deposits + top_up_deposits
 
     eth1_block_hash = b'\x13' * 32
-    eth1_timestamp = spec.MIN_GENESIS_TIME
+    eth1_timestamp = spec.config.MIN_GENESIS_TIME
 
-    yield 'eth1_block_hash', eth1_block_hash
-    yield 'eth1_timestamp', eth1_timestamp
+    yield from eth1_init_data(eth1_block_hash, eth1_timestamp)
     yield 'deposits', deposits
 
     # initialize beacon_state
@@ -125,10 +152,14 @@ def test_initialize_beacon_state_one_topup_activation(spec):
     yield 'state', state
 
 
-@with_phases([PHASE0])
+@with_all_phases
 @spec_test
 @single_phase
+@with_presets([MINIMAL], reason="too slow")
 def test_initialize_beacon_state_random_invalid_genesis(spec):
+    if is_post_altair(spec):
+        yield 'description', 'meta', get_post_altair_description(spec)
+
     # Make a bunch of random deposits
     deposits, _, deposit_data_list = prepare_random_genesis_deposits(
         spec,
@@ -136,10 +167,9 @@ def test_initialize_beacon_state_random_invalid_genesis(spec):
         max_pubkey_index=10,
     )
     eth1_block_hash = b'\x14' * 32
-    eth1_timestamp = spec.MIN_GENESIS_TIME + 1
+    eth1_timestamp = spec.config.MIN_GENESIS_TIME + 1
 
-    yield 'eth1_block_hash', eth1_block_hash
-    yield 'eth1_timestamp', eth1_timestamp
+    yield from eth1_init_data(eth1_block_hash, eth1_timestamp)
     yield 'deposits', deposits
 
     # initialize beacon_state
@@ -149,33 +179,36 @@ def test_initialize_beacon_state_random_invalid_genesis(spec):
     yield 'state', state
 
 
-@with_phases([PHASE0])
+@with_all_phases
 @spec_test
 @single_phase
+@with_presets([MINIMAL], reason="too slow")
 def test_initialize_beacon_state_random_valid_genesis(spec):
+    if is_post_altair(spec):
+        yield 'description', 'meta', get_post_altair_description(spec)
+
     # Make a bunch of random deposits
     random_deposits, _, deposit_data_list = prepare_random_genesis_deposits(
         spec,
         deposit_count=20,
-        min_pubkey_index=spec.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT - 5,
-        max_pubkey_index=spec.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT + 5,
+        min_pubkey_index=spec.config.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT - 5,
+        max_pubkey_index=spec.config.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT + 5,
     )
 
-    # Then make spec.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT full deposits
+    # Then make spec.config.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT full deposits
     full_deposits, _, _ = prepare_full_genesis_deposits(
         spec,
         spec.MAX_EFFECTIVE_BALANCE,
-        deposit_count=spec.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT,
+        deposit_count=spec.config.MIN_GENESIS_ACTIVE_VALIDATOR_COUNT,
         signed=True,
         deposit_data_list=deposit_data_list
     )
 
     deposits = random_deposits + full_deposits
     eth1_block_hash = b'\x15' * 32
-    eth1_timestamp = spec.MIN_GENESIS_TIME + 2
+    eth1_timestamp = spec.config.MIN_GENESIS_TIME + 2
 
-    yield 'eth1_block_hash', eth1_block_hash
-    yield 'eth1_timestamp', eth1_timestamp
+    yield from eth1_init_data(eth1_block_hash, eth1_timestamp)
     yield 'deposits', deposits
 
     # initialize beacon_state
